@@ -5,7 +5,7 @@ from frasco.request_params import disable_request_params
 from frasco.marshaller import disable_marshaller
 from werkzeug.wrappers import Response
 import functools
-from .swagger import build_swagger_spec, build_swagger_client
+from .swagger import build_swagger_spec
 from .errors import *
 
 
@@ -15,7 +15,7 @@ def wrap_service_func_for_endpoint(func):
         try:
             rv = func(*args, **kwargs)
         except ApiError as e:
-            return make_response(json.dumps({"error": unicode(e)}), e.http_code)
+            return make_response(json.dumps({"error": str(e)}), e.http_code)
         if isinstance(rv, Response):
             return rv
         return json.dumps(rv), {'Content-Type': 'application/json;charset=UTF-8'}
@@ -31,12 +31,13 @@ def wrap_service_func_for_internal_call(func):
 
 
 class ApiService(object):
-    def __init__(self, name=None, url_prefix=None):
+    def __init__(self, name=None, url_prefix=None, description=None):
         self.name = name
         self.url_prefix = url_prefix
         self.rules = []
         self.endpoint_funcs = {}
         self.decorators = []
+        self.description = description
 
     def add_endpoint(self, rule, func, **options):
         endpoint = options.pop("endpoint", func.__name__)
@@ -61,6 +62,10 @@ class ApiService(object):
         kwargs['methods'] = ['POST']
         return self.route(*args, **kwargs)
 
+    def PATCH(self, *args, **kwargs):
+        kwargs['methods'] = ['PATCH']
+        return self.route(*args, **kwargs)
+
     def PUT(self, *args, **kwargs):
         kwargs['methods'] = ['PUT']
         return self.route(*args, **kwargs)
@@ -156,12 +161,12 @@ class ApiVersion(ApiService):
         for rule, endpoint, options in rules:
             yield rule, endpoint, endpoint_funcs[endpoint], options
 
-    def as_blueprint(self, name=None, client_var_name="API", client_class_name="SwaggerClient", spec_builder_options=None):
+    def as_blueprint(self, name=None, cors_wildcard=True, cors_allow_credentials=False, spec_builder_options=None, **blueprint_options):
         if not spec_builder_options:
             spec_builder_options = {}
         if not name:
             name = "api_%s" % self.version.replace('.', '_')
-        bp = self.blueprint_class(name, self.import_name, url_prefix=self.url_prefix)
+        bp = self.blueprint_class(name, self.import_name, url_prefix=self.url_prefix, **blueprint_options)
 
         @bp.before_request
         def before_request():
@@ -171,6 +176,10 @@ class ApiVersion(ApiService):
         def after_request(resp):
             resp.headers.add('Cache-Control', 'no-cache')
             resp.headers.add('X-Api-Version', self.version)
+            if cors_wildcard:
+                resp.headers.add('Access-Control-Allow-Origin', '*')
+                if cors_allow_credentials:
+                    resp.headers.add('Access-Control-Allow-Credentials', 'true')
             return resp
 
         endpoint_funcs = {}
@@ -182,9 +191,4 @@ class ApiVersion(ApiService):
         def get_spec():
             return jsonify(**self.build_apispec(**spec_builder_options))
 
-        @bp.route("/client.js")
-        def get_client():
-            return build_swagger_client(self.build_apispec(**spec_builder_options),
-                url_for('.get_spec', _external=True), client_var_name, client_class_name)
-
         return bp
