@@ -22,7 +22,7 @@ def build_swagger_spec(api_version, with_security_scheme=False):
     for service in api_version.iter_services():
         paths = {}
         tag = {"name": service.name}
-        if hasattr(service, 'description'):
+        if service.description:
             tag["description"] = service.description
         spec.tag(tag)
         for rule, endpoint, func, options in service.iter_endpoints():
@@ -32,7 +32,7 @@ def build_swagger_spec(api_version, with_security_scheme=False):
                 op = build_spec_operation(rule, service.name + '_' + endpoint, func, options, with_security_scheme)
                 op['tags'] = [service.name]
                 path[method.lower()] = op
-        for path, operations in paths.iteritems():
+        for path, operations in paths.items():
             spec.path(path=path, operations=operations)
 
     return spec
@@ -121,14 +121,3 @@ def convert_type_to_spec(type):
     if type is bool:
         return "boolean"
     return "string"
-
-
-def build_swagger_client(spec, spec_url, var_name='API', class_name = 'SwaggerClient'):
-    return "function %s(options) { options['spec'] = %s; %s.call(this, '%s', options); } %s.prototype = new %s();" % (
-            var_name,
-            json.dumps(spec),
-            class_name,
-            spec_url,
-            var_name,
-            class_name
-        )
