@@ -19,7 +19,6 @@ EU_COUNTRIES = {
     "ES": "EUR", # Spain
     "FI": "EUR", # Finland
     "FR": "EUR", # France,
-    "GB": "GBP", # Great Britain
     "GR": "EUR", # Greece
     "HR": "HRK", # Croatia
     "HU": "HUF", # Hungary
@@ -51,7 +50,6 @@ KNOWN_VAT_RATES = {
     "ES": 21.0, # Spain
     "FI": 24.0, # Finland
     "FR": 20.0, # France,
-    "GB": 20.0, # Great Britain
     "GR": 23.0, # Greece
     "HR": 25.0, # Croatia
     "HU": 27.0, # Hungary
@@ -122,7 +120,7 @@ def get_vat_rate(country_code, rate_type='standard'):
             for rate in r.ratesResponse.rate:
                 _vat_rates_cache[country_code][rate.type.lower()] = float(rate.value)
         except Exception as e:
-            current_app.log_exception(e)
+            current_app.logger.debug(e)
             _vat_rates_cache.pop(country_code)
             return KNOWN_VAT_RATES.get(country_code)
     return _vat_rates_cache[country_code].get(rate_type.lower())
@@ -153,7 +151,7 @@ def fetch_exchange_rates():
             rates[cube.attrib['currency']] = float(cube.attrib['rate'])
         _exchange_rates_cache[today] = rates
     except Exception as e:
-        current_app.log_exception(e)
+        current_app.logger.debug(e)
     return rates
 
 
