@@ -5,10 +5,10 @@ from frasco.models import delayed_tx_calls
 from frasco.tasks import enqueue_task
 from frasco.templating.extensions import RemoveYamlFrontMatterExtension
 from frasco.utils import extract_unmatched_items, import_class, AttrDict
-from flask_mail import Mail
 from jinja_macro_tags import MacroLoader, MacroRegistry
 from jinja2 import ChoiceLoader, FileSystemLoader, PackageLoader
 from contextlib import contextmanager
+from flask_mail import Mail
 import os
 import datetime
 
@@ -45,7 +45,6 @@ class FrascoMail(Extension):
     """
     name = "frasco_mail"
     state_class = FrascoMailState
-    prefix_extra_options = "MAIL_"
     defaults = {"provider": "smtp",
                 "connections": {},
                 "default_layout": "layout.html",
@@ -63,15 +62,13 @@ class FrascoMail(Extension):
                 "send_async": False}
 
     def _init_app(self, app, state):
-        state.mail = Mail(app)
-
+        mail = Mail(app) # needed for Message even if we will never use
         connections = dict(state.options['connections'])
         if "default" not in connections:
             connections["default"] = dict(extract_unmatched_items(state.options, self.defaults or {}),
                 provider=state.require_option('provider'))
-        for provider, provider_opts in connections.items():
-            provider_class = import_class(provider_opts.get('provider', 'smtp'), MailProvider, "frasco.mail.providers")
-            state.connections[provider] = provider_class(app, state, provider_opts)
+        for name, opts in connections.items():
+            self.register_connection(name, opts, _app=app)
 
         state.add_template_folder(os.path.join(app.root_path, "emails"))
         state.jinja_env = app.jinja_env.overlay(loader=state.jinja_loader)
@@ -87,29 +84,43 @@ class FrascoMail(Extension):
             if state.options['localized_emails'] is None:
                 state.options['localized_emails'] = '{locale}/{filename}'
 
+    @ext_stateful_method
+    def create_connection(self, state, options, provider=None):
+        if not provider:
+            options = dict(**options)
+            provider = options.pop('provider', 'smtp')
+        provider_class = import_class(provider, MailProvider, "frasco.mail.providers")
+        return provider_class(state, options)
+
+    @ext_stateful_method
+    def register_connection(self, state, name, options, provider=None):
+        state.connections[name] = self.create_connection(options, provider, _state=state)
+
 
 @delayed_tx_calls.proxy
-def send_message_sync(msg, connection="default"):
+def send_message_sync(msg, connection="default", silent=None):
     state = get_extension_state('frasco_mail')
 
     if state.options['suppress_send']:
         if state.options["log_messages"] or current_app.testing or current_app.debug:
-            log_message(msg, state.options['dumped_messages_folder'])
+            log_message(msg, state.options['dumped_messages_folder'], connection)
         email_sent.send(msg)
         return
 
     try:
         if bulk_connection_context.top:
             bulk_connection_context.top.send(msg)
+        elif isinstance(connection, MailProvider):
+            connection.send(msg)
         else:
             state.connections[connection].send(msg)
         email_sent.send(msg)
         if state.options["log_messages"] or current_app.testing or current_app.debug:
-            log_message(msg, state.options['dumped_messages_folder'])
+            log_message(msg, state.options['dumped_messages_folder'], connection)
     except Exception as e:
         if state.options["log_messages_on_failure"]:
-            log_message(msg, state.options['dumped_messages_folder'])
-        if not state.options['silent_failures']:
+            log_message(msg, state.options['dumped_messages_folder'], connection)
+        if (silent is None and not state.options['silent_failures']) or silent is False:
             raise e
         current_app.log_exception(e)
 
