@@ -1,21 +1,22 @@
 import mimetypes
-from werkzeug import FileStorage, secure_filename
-from StringIO import StringIO
+from werkzeug.datastructures import FileStorage
+from werkzeug.utils import secure_filename as wz_secure_filename
+from io import StringIO, BytesIO
 from frasco.ext import get_extension_state
 from tempfile import NamedTemporaryFile, gettempdir
 import os
 import uuid
 
 
-__all__ = ('StringFileStorage', 'generate_filename', 'save_uploaded_file_temporarly', 'file_size', 'format_file_size')
+__all__ = ('BytesFileStorage', 'StringFileStorage', 'generate_filename', 'save_uploaded_file_temporarly', 'file_size', 'format_file_size')
 
 
 mimetypes.init()
 
 
-class StringFileStorage(FileStorage):
-    def __init__(self, data, filename, mimetype=None, **kwargs):
-        super(StringFileStorage, self).__init__(StringIO(data), filename, **kwargs)
+class BytesFileStorage(FileStorage):
+    def __init__(self, data, filename, mimetype=None, io_class=BytesIO, **kwargs):
+        super().__init__(io_class(data), filename, **kwargs)
         if mimetype is None:
             try:
                 mimetype = mimetypes.guess_type(filename)[0]
@@ -28,8 +29,14 @@ class StringFileStorage(FileStorage):
         return self._mimetype
 
 
+class StringFileStorage(BytesFileStorage):
+    def __init__(self, data, filename, mimetype=None, **kwargs):
+        kwargs['io_class'] = StringIO
+        super().__init__(data, filename, mimetype, **kwargs)
+
+
 def generate_filename(filename, uuid_prefix=None, uuid_prefix_path_separator=None, keep_filename=None,
-                      subfolders=None, backend=None):
+                      subfolders=None, backend=None, secure_filename=True):
 
     state = get_extension_state('frasco_upload', must_exist=False)
     if state:
@@ -46,7 +53,8 @@ def generate_filename(filename, uuid_prefix=None, uuid_prefix_path_separator=Non
         _, ext = os.path.splitext(filename)
         filename = str(uuid.uuid4()) + ext
     else:
-        filename = secure_filename(filename)
+        if secure_filename:
+            filename = wz_secure_filename(filename)
         if uuid_prefix:
             filename = str(uuid.uuid4()) + ("/" if uuid_prefix_path_separator else "-") + filename
 
@@ -71,7 +79,7 @@ def save_uploaded_file_temporarly(file, filename=None, tmp_dir=None):
     if not tmp_dir:
         tmp_dir = state.options.get('upload_tmp_dir') if state else None
     if filename:
-        tmpfilename = os.path.join(tmp_dir or gettempdir(), secure_filename(filename))
+        tmpfilename = os.path.join(tmp_dir or gettempdir(), wz_secure_filename(filename))
     else:
         _, ext = os.path.splitext(file.filename)
         tmp = NamedTemporaryFile(delete=False, suffix=ext, dir=tmp_dir)
