@@ -1,4 +1,4 @@
-from flask import has_request_context, _request_ctx_stack, flash, request, current_app
+from flask import has_request_context, _request_ctx_stack, flash, request, current_app, session
 import flask_login
 from flask_login.utils import _get_user
 from frasco.ext import get_extension_state, has_extension
@@ -9,8 +9,9 @@ from frasco.geoip import geolocate_country
 from contextlib import contextmanager
 from werkzeug.local import LocalProxy
 import datetime
-from .signals import user_signed_up
+from .signals import user_signed_up, email_validated
 from .password import update_password
+from .tokens import generate_user_token, TOKEN_NS_VALIDATE_EMAIL
 import logging
 
 
@@ -65,6 +66,7 @@ def is_user_logged_in():
 def login_user(user, *args, **kwargs):
     state = get_extension_state('frasco_users')
     provider = kwargs.pop('provider', state.options['default_auth_provider_name'])
+    skip_session = kwargs.pop('skip_session', False)
 
     for validator in state.login_validators:
         if not validator(user):
@@ -73,6 +75,11 @@ def login_user(user, *args, **kwargs):
     if not flask_login.login_user(user, *args, **kwargs):
         return False
 
+    if skip_session:
+        # remove the _user_id set by flask-login
+        # this will prevent setting the remember cookie and won't maintain the login state to the next request
+        session.pop('_user_id', None)
+
     user.last_login_at = datetime.datetime.utcnow()
     user.last_login_from = request.remote_addr
     user.last_login_provider = provider
@@ -99,7 +106,7 @@ def login_user(user, *args, **kwargs):
     return True
     
 
-def signup_user(email_or_user, password=None, provider=None, flash_messages=True, send_signal=True, **kwargs):
+def signup_user(email_or_user, password=None, provider=None, flash_messages=True, send_signal=True, validate_email=False, **kwargs):
     state = get_extension_state('frasco_users')
     if isinstance(email_or_user, state.Model):
         user = email_or_user
@@ -127,6 +134,11 @@ def signup_user(email_or_user, password=None, provider=None, flash_messages=True
     db.session.add(user)
     db.session.flush()
 
+    if validate_email:
+        validate_user_email(user)
+    elif state.options['send_email_validation_email']:
+        send_user_validation_email(user)
+
     if state.options["send_welcome_email"]:
         from frasco.mail import send_mail
         template = "users/welcome.txt" if state.options["send_welcome_email"] == True else state.options["send_welcome_email"]
@@ -239,6 +251,23 @@ def validate_user(user, ignore_self=True, flash_messages=True, raise_error=True,
     return True
 
 
+def generate_email_validation_token(user):
+    return generate_user_token(user, TOKEN_NS_VALIDATE_EMAIL)
+
+
+def send_user_validation_email(user):
+    from frasco.mail import send_mail
+    token = generate_email_validation_token(user)
+    send_mail(user.email, "users/validate_email", user=user, token=token, locale=getattr(user, 'locale', None))
+    return token
+
+
+def validate_user_email(user):
+    user.email_validated = True
+    user.email_validated_at = datetime.datetime.utcnow()
+    email_validated.send(user)
+
+
 def check_rate_limit(ip, remote_addr_prop, date_prop, flash_message=True):
     state = get_extension_state('frasco_users')
     since = datetime.datetime.now() - datetime.timedelta(seconds=state.options['rate_limit_period'])
